#! /bin/csh -f
#
#	basic Patterson script
#
set file1 = "merged.mtz"
set file2 = ""
set RESO = 2.6
set DIFF = ""
set SIG  = 0

if(-e "$1") set file1 = "$1"
if(-e "$2") set file2 = "$2"

set outfile  = Patt.map
set tempfile = "patt_temp"

if(-e "$file2") goto iso

# apply an evelope-matching noise supression filter? 
set rolloff = `echo $RESO | awk '{print 8.8*$1*$1}'`

######################
if("$DIFF" == "") then
    # use scalit to get a good maximum-difference cutoff
    scaleit hklin $file1 << EOF >&! ${tempfile}scale.log
    analyze
    labin FP=DANO SIGFP=SIGDANO FPH1=F SIGFPH1=SIGF
    scale FPH1 0.0000001
    END
EOF
    set DIFF = `awk '/acceptable differences/{print $NF}' ${tempfile}scale.log`
    rm -f ${tempfile}scale.log >& /dev/null
endif

######################
# anomalous Patterson
fft hklin $file1 mapout ${tempfile}.map << EOF-fft 
PATTERSON
RESOLUTION $RESO
LABIN F1=DANO SIG1=SIGDANO F2=F SIG2=SIGF
SCALE F1 1 $rolloff
SCALE F2 0.000001 0
EXCLUDE DIFF $DIFF
EXCLUDE SIG1 $SIG
EOF-fft
goto norm

iso:
######################
# isomorphous (dispersive) difference

# put both data sets into same file
cad hklin1 $file1 hklin2 $file2 \
    hklout ${tempfile}.mtz << EOF-cad
LABIN file 1 E1=F  E2=SIGF
LABOU file 1 E1=F1 E2=SIGF1
LABIN file 2 E1=F  E2=SIGF
LABOU file 2 E1=F2 E2=SIGF2
EOF-cad

if(! $?SCALED) then
    # need to scale input files together
    scaleit HKLIN ${tempfile}.mtz \
           HKLOUT ${tempfile}scaled.mtz << EOF-scaleit | tee ${tempfile}log
LABIN FP=F1  SIGFP=SIGF1 FPH1=F2 SIGFPH1=SIGF2 
#RESO $RESO 1000	# exclude lowest resolution data? 
#WEIGHT			# Sigmas should be reliable.
refine anisotropic	# use an anisotropic B-factor
#refine isotropic	# use an isotropic B-factor
#norefine		# don't change relative scale
END
EOF-scaleit
    # now this is the file we want to use for fft
    mv ${tempfile}scaled.mtz ${tempfile}.mtz

    if("$DIFF" == "") then
	# auto-set DIFF from scaleit output
	set DIFF = `awk '/acceptable differences/{print $NF}' ${tempfile}log`
    endif
    rm -f ${tempfile}log >& /dev/null
endif

######################
# do the Patterson
fft hklin ${tempfile}.mtz mapout ${tempfile}.map << EOF-fft 
PATTERSON
LABIN F1=F1 SIG1=SIGF1 F2=F2 SIG2=SIGF2
RESOLUTION $RESO
SCALE F1 1 $rolloff
SCALE F2 1 $rolloff
EXCLUDE DIFF $DIFF
EXCLUDE SIG1 $SIG
EXCLUDE SIG2 $SIG
EOF-fft
goto norm



norm:
# normalize the output map
echo "SCALE SIGMA" |\
mapmask mapin ${tempfile}.map mapout $outfile

# quick peak-pick (for the log)
peakmax mapin $outfile PEAKS ${tempfile}.xyz TO ${tempfile}.xyz << eof-pick
THRESHOLD RMS 3
OUTPUT PEAKS
END
eof-pick

# clean up
rm -f ${tempfile}.map >& /dev/null
rm -f ${tempfile}.mtz >& /dev/null
rm -f ${tempfile}.xyz >& /dev/null

